<?php

/**
 * The settings of the plugin.
 *
 * @link       https://profile.wordpress.org/apsaraaruna
 * @since      1.0.0
 *
 * @package    Five_R_Gig
 * @subpackage Five_R_Gig/admin
 */

/**
 * Class WordPress_Plugin_Template_Settings
 *
 */
class Five_R_Gig_Admin_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * This function introduces the theme options into the 'Appearance' menu and into a top-level
	 * 'Five R Gig' menu.
	 */
	public function setup_plugin_options_menu() {

		//Add the menu to the Plugins set of menu items
		add_plugins_page(
			'Five R Gig Options', 					// The title to be displayed in the browser window for this page.
			'Five R Gig Options',					// The text to be displayed for this menu item
			'manage_options',					// Which type of users can see this menu item
			'five_r_gig',			// The unique ID - that is, the slug - for this menu item
			array( $this, 'render_settings_page_content')				// The name of the function to call when rendering this menu's page
		);

	}

	/**
	 * Provides default values for the Display Options.
	 *
	 * @return array
	 */
	public function default_display_options() {

		$defaults = array(
			'fontawesome'		=>	'',
			'show_content'		=>	'',
			'show_footer'		=>	'',
		);

		return $defaults;

	}

	/**
	 * Provide default values for the Social Options.
	 *
	 * @return array
	 */
	public function default_about_options() {

		$defaults = array(
			'twitter'		=>	'twitter',
			'facebook'		=>	'',
			'googleplus'	=>	'',
		);

		return  $defaults;

	}

	/**
	 * Provides default values for the Input Options.
	 *
	 * @return array
	 */
	public function default_input_options() {

		$defaults = array(
			'input_example'		=>	'default input example',
			'textarea_example'	=>	'',
			'checkbox_example'	=>	'',
			'radio_example'		=>	'2',
			'time_options'		=>	'default'
		);

		return $defaults;

	}

	/**
	 * Renders a simple page to display for the theme menu defined above.
	 */
	public function render_settings_page_content( $active_tab = '' ) {
		?>
		<!-- Create a header in the default WordPress 'wrap' container -->
		<div class="wrap">

			<h2><?php _e( 'Five R Gig Options', 'five-r-gig' ); ?></h2>
			<?php settings_errors(); ?>

			<?php if( isset( $_GET[ 'tab' ] ) ) {
				$active_tab = esc_html($_GET[ 'tab' ]);
			} else if( $active_tab == 'about_options' ) {
				$active_tab = 'about_options';
			} else if( $active_tab == 'input_examples' ) {
				$active_tab = 'input_examples';
			} else {
				$active_tab = 'display_options';
			} // end if/else ?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=five_r_gig&tab=display_options" class="nav-tab <?php echo $active_tab == 'display_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Display Options', 'five-r-gig' ); ?></a>
				<a href="?page=five_r_gig&tab=about_options" class="nav-tab <?php echo $active_tab == 'about_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'About', 'five-r-gig' ); ?></a>
				<!-- <a href="?page=five_r_gig&tab=input_examples" class="nav-tab <?php echo $active_tab == 'input_examples' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Input Examples', 'five-r-gig' ); ?></a> -->
			</h2>

			<form method="post" action="options.php">
				<?php

				if( $active_tab == 'display_options' ) {

					settings_fields( 'five_r_gig_display_options' );
					do_settings_sections( 'five_r_gig_display_options' );
					submit_button();
				} elseif( $active_tab == 'about_options' ) {

					settings_fields( 'five_r_gig_about_options' );
					do_settings_sections( 'five_r_gig_about_options' );

				} else {

					// settings_fields( 'five_r_gig_input_examples' );
					// do_settings_sections( 'five_r_gig_input_examples' );

				} // end if/else

				// submit_button();

				?>
			</form>

		</div><!-- /.wrap -->
		<?php
	}


	/**
	 * This function provides a simple description for the General Options page.
	 *
	 * It's called from the 'five-r-gig_initialize_theme_options' function by being passed as a parameter
	 * in the add_settings_section function.
	 */
	public function general_options_callback() {
		$options = get_option('five_r_gig_display_options');
		// var_dump($options);
		echo '<p>' . __( 'Select which areas of content you wish to display.', 'five-r-gig' ) . '</p>';
	} // end general_options_callback


	public function about_options_callback() {
		echo '
		<p> <a href="https://wordpress.org/plugins/widget-youtube-subscribtion/" target="_blank">Easy Subscribe Button Widget >></a></p>
		<p> <a href="https://wordpress.org/plugins/popup-notification-news-alert/" target="_blank">Toast Popup Notification News Alert >></a></p>
		<p> <a href="https://wordpress.org/plugins/embed-page-facebook/" target="_blank">Easy Embed Page Widget >></a></p>

		';
	} 

	public function frg_fontawesome(){
		$options = get_option('five_r_gig_display_options');

		if ($options['fontawesome'] == 1) {
			return wp_enqueue_script( 'frg-fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.13.0/js/all.min.js', array( 'jquery' ), '5.13.0', true );
		}
	}
	/**
	 * This function provides a simple description for the Social Options page.
	 *
	 * It's called from the 'five-r-gig_theme_initialize_about_options' function by being passed as a parameter
	 * in the add_settings_section function.
	 */
	// public function about_options_callback() {
	// 	$options = get_option('five_r_gig_about_options');
	// 	var_dump($options);
	// 	echo '<p>' . __( 'Provide the URL to the social networks you\'d like to display.', 'five-r-gig' ) . '</p>';
	// } 
	// end general_options_callback

	/**
	 * This function provides a simple description for the Input Examples page.
	 *
	 * It's called from the 'five-r-gig_theme_initialize_input_examples_options' function by being passed as a parameter
	 * in the add_settings_section function.
	 */
	public function input_examples_callback() {
		$options = get_option('five_r_gig_input_examples');
		var_dump($options);
		echo '<p>' . __( 'Provides examples of the five basic element types.', 'five-r-gig' ) . '</p>';
	} // end general_options_callback


	/**
	 * Initializes the theme's display options page by registering the Sections,
	 * Fields, and Settings.
	 *
	 * This function is registered with the 'admin_init' hook.
	 */
	public function initialize_display_options() {

		// If the theme options don't exist, create them.
		if( false == get_option( 'five_r_gig_display_options' ) ) {
			$default_array = $this->default_display_options();
			add_option( 'five_r_gig_display_options', $default_array );
		}


		add_settings_section(
			'general_settings_section',			            // ID used to identify this section and with which to register options
			__( 'Display Options', 'five-r-gig' ),		        // Title to be displayed on the administration page
			array( $this, 'general_options_callback'),	    // Callback used to render the description of the section
			'five_r_gig_display_options'		                // Page on which to add this section of options
		);

		// Next, we'll introduce the fields for toggling the visibility of content elements.
		add_settings_field(
			'fontawesome',						        // ID used to identify the field throughout the theme
			__( 'Enable Fontawesome', 'five-r-gig' ),					// The label to the left of the option interface element
			array( $this, 'toggle_header_callback'),	// The name of the function responsible for rendering the option interface
			'five_r_gig_display_options',	            // The page on which this option will be displayed
			'general_settings_section',			        // The name of the section to which this field belongs
			array(								        // The array of arguments to pass to the callback. In this case, just a description.
				__( 'If your site doen\'t have fontawesome, widget social icon doesn\'t show. you can enable from here.' , 'five-r-gig' ),
			)
		);
		add_settings_field(
			'facebook',
			'Facebook',
			array( $this, 'toggle_facebook_callback'),
			'five_r_gig_display_options',
			'general_settings_section'
		);
		add_settings_field(
			'twitter',
			'Twitter',
			array( $this, 'toggle_twitter_callback'),
			'five_r_gig_display_options',
			'general_settings_section'
		);
		add_settings_field(
			'instagram',
			'Instagram',
			array( $this, 'toggle_insta_callback'),
			'five_r_gig_display_options',
			'general_settings_section'
		);
		add_settings_field(
			'linkedin',
			'Linkedin',
			array( $this, 'toggle_linkedin_callback'),
			'five_r_gig_display_options',
			'general_settings_section'
		);


		// Finally, we register the fields with WordPress
		register_setting(
			'five_r_gig_display_options',
			'five_r_gig_display_options',
			array( $this, 'sanitize_social_options')
		);

	} // end five-r-gig_initialize_theme_options


	/**
	 * Initializes the theme's social options by registering the Sections,
	 * Fields, and Settings.
	 *
	 * This function is registered with the 'admin_init' hook.
	 */
	public function initialize_about_options() {
		add_settings_section(
			'social_settings_section',			// ID used to identify this section and with which to register options
			__( 'You may also like this plugin', 'five-r-gig' ),		// Title to be displayed on the administration page
			array( $this, 'about_options_callback'),	// Callback used to render the description of the section
			'five_r_gig_about_options'		// Page on which to add this section of options
		);



	}


	/**
	 * This function renders the interface elements for toggling the visibility of the header element.
	 *
	 * It accepts an array or arguments and expects the first element in the array to be the description
	 * to be displayed next to the checkbox.
	 */
	public function toggle_header_callback($args) {

		// First, we read the options collection
		$options = get_option('five_r_gig_display_options');

		// Next, we update the name attribute to access this element's ID in the context of the display options array
		// We also access the fontawesome element of the options collection in the call to the checked() helper function
		$html = '<input type="checkbox" id="fontawesome" name="five_r_gig_display_options[fontawesome]" value="1" ' . checked( 1, isset( $options['fontawesome'] ) ? $options['fontawesome'] : 0, false ) . '/>';

		// Here, we'll take the first argument of the array and add it to a label next to the checkbox
		$html .= '<label for="fontawesome">&nbsp;'  . $args[0] . '</label>';

		echo $html;

	} // end toggle_header_callback

	public function toggle_twitter_callback($args) {

		$options = get_option('five_r_gig_display_options');

		$url = '';
		if( isset( $options['twitter'] ) ) {
			$url = esc_url( $options['twitter'] );
		} // end if

		// Render the output
		echo '<input type="text" id="twitter" name="five_r_gig_display_options[twitter]" value="' . $url . '" />';

	} // end toggle_twitter_callback

	public function toggle_facebook_callback($args) {

		$options = get_option('five_r_gig_display_options');

		$url = '';
		if( isset( $options['facebook'] ) ) {
			$url = esc_url( $options['facebook'] );
		} // end if

		// Render the output
		echo '<input type="text" id="facebook" name="five_r_gig_display_options[facebook]" value="' . $url . '" />';

	} // end toggle_footer_callback	
	public function toggle_insta_callback($args) {

		$options = get_option('five_r_gig_display_options');

		$url = '';
		if( isset( $options['instagram'] ) ) {
			$url = esc_url( $options['instagram'] );
		} // end if

		// Render the output
		echo '<input type="text" id="instagram" name="five_r_gig_display_options[instagram]" value="' . $url . '" />';

	} // end toggle_footer_callback	
	public function toggle_linkedin_callback($args) {

		$options = get_option('five_r_gig_display_options');

		$url = '';
		if( isset( $options['linkedin'] ) ) {
			$url = esc_url( $options['linkedin'] );
		} // end if

		// Render the output
		echo '<input type="text" id="linkedin" name="five_r_gig_display_options[linkedin]" value="' . $url . '" />';

	} // end toggle_footer_callback




	public function input_element_callback() {

		$options = get_option( 'five_r_gig_input_examples' );

		// Render the output
		echo '<input type="text" id="input_example" name="five_r_gig_input_examples[input_example]" value="' . $options['input_example'] . '" />';

	} // end input_element_callback

	public function textarea_element_callback() {

		$options = get_option( 'five_r_gig_input_examples' );

		// Render the output
		echo '<textarea id="textarea_example" name="five_r_gig_input_examples[textarea_example]" rows="5" cols="50">' . $options['textarea_example'] . '</textarea>';

	} // end textarea_element_callback

	public function checkbox_element_callback() {

		$options = get_option( 'five_r_gig_input_examples' );

		$html = '<input type="checkbox" id="checkbox_example" name="five_r_gig_input_examples[checkbox_example]" value="1"' . checked( 1, $options['checkbox_example'], false ) . '/>';
		$html .= '&nbsp;';
		$html .= '<label for="checkbox_example">This is an example of a checkbox</label>';

		echo $html;

	} // end checkbox_element_callback

	public function radio_element_callback() {

		$options = get_option( 'five_r_gig_input_examples' );

		$html = '<input type="radio" id="radio_example_one" name="five_r_gig_input_examples[radio_example]" value="1"' . checked( 1, $options['radio_example'], false ) . '/>';
		$html .= '&nbsp;';
		$html .= '<label for="radio_example_one">Option One</label>';
		$html .= '&nbsp;';
		$html .= '<input type="radio" id="radio_example_two" name="five_r_gig_input_examples[radio_example]" value="2"' . checked( 2, $options['radio_example'], false ) . '/>';
		$html .= '&nbsp;';
		$html .= '<label for="radio_example_two">Option Two</label>';

		echo $html;

	} // end radio_element_callback

	public function select_element_callback() {

		$options = get_option( 'five_r_gig_input_examples' );

		$html = '<select id="time_options" name="five_r_gig_input_examples[time_options]">';
		$html .= '<option value="default">' . __( 'Select a time option...', 'five-r-gig' ) . '</option>';
		$html .= '<option value="never"' . selected( $options['time_options'], 'never', false) . '>' . __( 'Never', 'five-r-gig' ) . '</option>';
		$html .= '<option value="sometimes"' . selected( $options['time_options'], 'sometimes', false) . '>' . __( 'Sometimes', 'five-r-gig' ) . '</option>';
		$html .= '<option value="always"' . selected( $options['time_options'], 'always', false) . '>' . __( 'Always', 'five-r-gig' ) . '</option>';	$html .= '</select>';

		echo $html;

	} // end select_element_callback


	/**
	 * Sanitization callback for the social options. Since each of the social options are text inputs,
	 * this function loops through the incoming option and strips all tags and slashes from the value
	 * before serializing it.
	 *
	 * @params	$input	The unsanitized collection of options.
	 *
	 * @returns			The collection of sanitized values.
	 */
	public function sanitize_about_options( $input ) {

		// Define the array for the updated options
		$output = array();

		// Loop through each of the options sanitizing the data
		foreach( $input as $key => $val ) {

			if( isset ( $input[$key] ) ) {
				$output[$key] = esc_url_raw( strip_tags( stripslashes( $input[$key] ) ) );
			} // end if

		} // end foreach

		// Return the new collection
		return apply_filters( 'sanitize_about_options', $output, $input );

	} // end sanitize_about_options

	public function validate_input_examples( $input ) {

		// Create our array for storing the validated options
		$output = array();

		// Loop through each of the incoming options
		foreach( $input as $key => $value ) {

			// Check to see if the current option has a value. If so, process it.
			if( isset( $input[$key] ) ) {

				// Strip all HTML and PHP tags and properly handle quoted strings
				$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );

			} // end if

		} // end foreach

		// Return the array processing any additional functions filtered by this action
		return apply_filters( 'validate_input_examples', $output, $input );

	} // end validate_input_examples




}